#[repr(i32)]pub enum ResultCode {
Show 39 variants
Succeeded = 0,
IncompatibleVersion = 1,
MaximumDataIdAlias = 2,
MaximumUpstreamAlias = 3,
UnspecifiedError = 64,
NoNodeId = 65,
AuthFailed = 66,
ConnectTimeout = 67,
MalformedMessage = 68,
ProtocolError = 69,
AckTimeout = 70,
InvalidPayload = 71,
InvalidDataId = 72,
InvalidDataIdAlias = 73,
InvalidDataFilter = 74,
StreamNotFound = 75,
ResumeRequestConflict = 76,
ProcessFailed = 77,
DesiredQosNotSupported = 78,
PingTimeout = 79,
TooLargeMessageSize = 80,
TooManyDataIdAliases = 81,
TooManyStreams = 82,
TooLongAckInterval = 83,
TooManyDownstreamFilters = 84,
TooManyDataFilters = 85,
TooLongExpiryInterval = 86,
TooLongPingTimeout = 87,
TooShortPingInterval = 88,
TooShortPingTimeout = 89,
RateLimitReached = 90,
TooLargeFeedId = 91,
TooManyTargetNodes = 92,
FeedNotFound = 93,
InvalidResumeToken = 94,
NodeIdMismatch = 128,
SessionNotFound = 129,
SessionAlreadyClosed = 130,
SessionCannotClosed = 131,
}Variants
Succeeded = 0
IncompatibleVersion = 1
MaximumDataIdAlias = 2
MaximumUpstreamAlias = 3
UnspecifiedError = 64
NoNodeId = 65
AuthFailed = 66
ConnectTimeout = 67
MalformedMessage = 68
ProtocolError = 69
AckTimeout = 70
InvalidPayload = 71
InvalidDataId = 72
InvalidDataIdAlias = 73
InvalidDataFilter = 74
StreamNotFound = 75
ResumeRequestConflict = 76
ProcessFailed = 77
DesiredQosNotSupported = 78
PingTimeout = 79
TooLargeMessageSize = 80
TooManyDataIdAliases = 81
TooManyStreams = 82
TooLongAckInterval = 83
TooManyDownstreamFilters = 84
TooManyDataFilters = 85
TooLongExpiryInterval = 86
TooLongPingTimeout = 87
TooShortPingInterval = 88
TooShortPingTimeout = 89
RateLimitReached = 90
TooLargeFeedId = 91
TooManyTargetNodes = 92
FeedNotFound = 93
InvalidResumeToken = 94
NodeIdMismatch = 128
SessionNotFound = 129
SessionAlreadyClosed = 130
SessionCannotClosed = 131
Implementations
Sourceimpl ResultCode
impl ResultCode
Sourceimpl ResultCode
impl ResultCode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.