pub struct DownstreamCall {
pub call_id: String,
pub request_call_id: String,
pub source_node_id: String,
pub name: String,
pub type_: String,
pub payload: Bytes,
pub extension_fields: Option<DownstreamCallExtensionFields>,
}Fields
call_id: Stringrequest_call_id: Stringsource_node_id: Stringname: Stringtype_: Stringpayload: Bytesextension_fields: Option<DownstreamCallExtensionFields>Trait Implementations
Sourceimpl Clone for DownstreamCall
impl Clone for DownstreamCall
Sourcefn clone(&self) -> DownstreamCall
fn clone(&self) -> DownstreamCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DownstreamCall
impl Debug for DownstreamCall
Sourceimpl Default for DownstreamCall
impl Default for DownstreamCall
Sourceimpl<'de> Deserialize<'de> for DownstreamCall
impl<'de> Deserialize<'de> for DownstreamCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<DownstreamCall> for Message
impl From<DownstreamCall> for Message
Sourcefn from(m: DownstreamCall) -> Self
fn from(m: DownstreamCall) -> Self
Converts to this type from the input type.
Sourceimpl Message for DownstreamCall
impl Message for DownstreamCall
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for DownstreamCall
impl PartialEq for DownstreamCall
Sourceimpl Serialize for DownstreamCall
impl Serialize for DownstreamCall
impl StructuralPartialEq for DownstreamCall