pub struct DownstreamMetadata {
pub request_id: u32,
pub stream_id_alias: u32,
pub source_node_id: String,
pub extension_fields: Option<DownstreamMetadataExtensionFields>,
pub metadata: Option<Metadata>,
}Fields
request_id: u32stream_id_alias: u32source_node_id: Stringextension_fields: Option<DownstreamMetadataExtensionFields>metadata: Option<Metadata>Trait Implementations
Sourceimpl Clone for DownstreamMetadata
impl Clone for DownstreamMetadata
Sourcefn clone(&self) -> DownstreamMetadata
fn clone(&self) -> DownstreamMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DownstreamMetadata
impl Debug for DownstreamMetadata
Sourceimpl Default for DownstreamMetadata
impl Default for DownstreamMetadata
Sourceimpl<'de> Deserialize<'de> for DownstreamMetadata
impl<'de> Deserialize<'de> for DownstreamMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<DownstreamMetadata> for Message
impl From<DownstreamMetadata> for Message
Sourcefn from(m: DownstreamMetadata) -> Self
fn from(m: DownstreamMetadata) -> Self
Converts to this type from the input type.
Sourceimpl HasRequestId for DownstreamMetadata
impl HasRequestId for DownstreamMetadata
fn request_id(&self) -> u32
fn set_request_id(&mut self, request_id: u32)
Sourceimpl Message for DownstreamMetadata
impl Message for DownstreamMetadata
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for DownstreamMetadata
impl PartialEq for DownstreamMetadata
Sourceimpl Serialize for DownstreamMetadata
impl Serialize for DownstreamMetadata
impl StructuralPartialEq for DownstreamMetadata