pub struct UpstreamCloseRequest {
pub request_id: u32,
pub stream_id: Bytes,
pub total_data_points: u64,
pub final_sequence_number: u32,
pub extension_fields: Option<UpstreamCloseRequestExtensionFields>,
}Fields
request_id: u32stream_id: Bytestotal_data_points: u64final_sequence_number: u32extension_fields: Option<UpstreamCloseRequestExtensionFields>Trait Implementations
Sourceimpl Clone for UpstreamCloseRequest
impl Clone for UpstreamCloseRequest
Sourcefn clone(&self) -> UpstreamCloseRequest
fn clone(&self) -> UpstreamCloseRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpstreamCloseRequest
impl Debug for UpstreamCloseRequest
Sourceimpl Default for UpstreamCloseRequest
impl Default for UpstreamCloseRequest
Sourceimpl<'de> Deserialize<'de> for UpstreamCloseRequest
impl<'de> Deserialize<'de> for UpstreamCloseRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<UpstreamCloseRequest> for Message
impl From<UpstreamCloseRequest> for Message
Sourcefn from(m: UpstreamCloseRequest) -> Self
fn from(m: UpstreamCloseRequest) -> Self
Converts to this type from the input type.
Sourceimpl HasRequestId for UpstreamCloseRequest
impl HasRequestId for UpstreamCloseRequest
fn request_id(&self) -> u32
fn set_request_id(&mut self, request_id: u32)
Sourceimpl Message for UpstreamCloseRequest
impl Message for UpstreamCloseRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for UpstreamCloseRequest
impl PartialEq for UpstreamCloseRequest
Sourceimpl Serialize for UpstreamCloseRequest
impl Serialize for UpstreamCloseRequest
impl StructuralPartialEq for UpstreamCloseRequest