pub struct UpstreamResumeRequest {
pub request_id: u32,
pub stream_id: Bytes,
pub extension_fields: Option<UpstreamResumeRequestExtensionFields>,
pub resume_token: String,
}Fields
request_id: u32stream_id: Bytesextension_fields: Option<UpstreamResumeRequestExtensionFields>resume_token: StringTrait Implementations
Sourceimpl Clone for UpstreamResumeRequest
impl Clone for UpstreamResumeRequest
Sourcefn clone(&self) -> UpstreamResumeRequest
fn clone(&self) -> UpstreamResumeRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpstreamResumeRequest
impl Debug for UpstreamResumeRequest
Sourceimpl Default for UpstreamResumeRequest
impl Default for UpstreamResumeRequest
Sourceimpl<'de> Deserialize<'de> for UpstreamResumeRequest
impl<'de> Deserialize<'de> for UpstreamResumeRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<UpstreamResumeRequest> for Message
impl From<UpstreamResumeRequest> for Message
Sourcefn from(m: UpstreamResumeRequest) -> Self
fn from(m: UpstreamResumeRequest) -> Self
Converts to this type from the input type.
Sourceimpl HasRequestId for UpstreamResumeRequest
impl HasRequestId for UpstreamResumeRequest
fn request_id(&self) -> u32
fn set_request_id(&mut self, request_id: u32)
Sourceimpl Message for UpstreamResumeRequest
impl Message for UpstreamResumeRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for UpstreamResumeRequest
impl PartialEq for UpstreamResumeRequest
Sourceimpl Serialize for UpstreamResumeRequest
impl Serialize for UpstreamResumeRequest
impl StructuralPartialEq for UpstreamResumeRequest